"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("./internal/tslib.js");
/** @deprecated Import from ./core/resource instead */
tslib_1.__exportStar(require("./core/resource.js"), exports);//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/6928394f91b684055b873eecb8bc281365131f1c/node_modules/@anthropic-ai/sdk/resource.js.map