"use strict";
// Copyright (c) Microsoft Corporation.
// Licensed under the MIT license.
Object.defineProperty(exports, "__esModule", { value: true });
//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/6928394f91b684055b873eecb8bc281365131f1c/node_modules/@microsoft/dev-tunnels-management/tunnelRequestOptions.js.map