// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
export { useInstrumenter } from "./instrumenter.js";
export { createTracingClient } from "./tracingClient.js";//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/6928394f91b684055b873eecb8bc281365131f1c/node_modules/@azure/core-tracing/dist/esm/index.js.map